import java.awt.*;
import javax.swing.ImageIcon;

public class Main
{
    public static void main(String args[]) {
        Main test = new Main();
        test.run();
    }

    private static final DisplayMode POSSIBLE_MODES[] = {
            new DisplayMode(1024, 768, 32, 0),
            new DisplayMode(1024, 768, 24, 0)
    };

    private static final long DEMO_TIME = 10000;

    private ScreenManager iScreen;
    private Image iBGImage;
    private Animation iAnimation;


    public void loadImages() {
        // load images
        iBGImage = loadImage("images/background.jpg");
        Image player1 = loadImage("images/player1.png");
        Image player2 = loadImage("images/player2.png");
        Image player3 = loadImage("images/player3.png");

        // create animation
        iAnimation = new Animation();
        iAnimation.addFrame(player1, 250);
        iAnimation.addFrame(player2, 150);
        iAnimation.addFrame(player1, 150);
        iAnimation.addFrame(player2, 150);
        iAnimation.addFrame(player3, 200);
        iAnimation.addFrame(player2, 150);
    }


    private Image loadImage(String fileName) {
        return new ImageIcon(fileName).getImage();
    }


    public void run() {
        iScreen = new ScreenManager();
        try {
            DisplayMode displayMode = iScreen.findFirstCompatibleMode(POSSIBLE_MODES);
            iScreen.setFullScreen(displayMode);
            loadImages();
            
            animationLoop();
        }
        finally {
            iScreen.restoreScreen();
        }
    }



    public void animationLoop() {
        long startTime = System.currentTimeMillis();
        long currTime = startTime;

        while (currTime - startTime < DEMO_TIME) {
            long elapsedTime = System.currentTimeMillis() - currTime;
            currTime += elapsedTime;

            // update animation
            iAnimation.update(elapsedTime);

            // draw and update iScreen
            Graphics2D g = iScreen.getGraphics();
            draw(g);
            g.dispose();
            iScreen.update();  // <----- NOTE

            // take a nap
            try {
                Thread.sleep(20);
            }
            catch (InterruptedException ex) { }
        }

    }



    public void draw(Graphics g) {
        // draw background
        g.drawImage(iBGImage, 0, 0, null);

        // draw image
        g.drawImage(iAnimation.getImage(), 0, 0, null);
    }

}
